pub struct Ref<T: RefCountable> { /* private fields */ }Implementations
Sourceimpl Ref<LowLevelILFunction<Mutable, NonSSA>>
impl Ref<LowLevelILFunction<Mutable, NonSSA>>
Sourcepub fn finalized(self) -> Ref<LowLevelILFunction<Finalized, NonSSA>>
pub fn finalized(self) -> Ref<LowLevelILFunction<Finalized, NonSSA>>
Finalize the mutated LowLevelILFunction, returning a LowLevelILRegularFunction.
This function will not correct the SSA related dataflow, to do that you must call
the function LowLevelILMutableFunction::generate_ssa_form.
Example
use binaryninja::low_level_il::LowLevelILMutableFunction;
use binaryninja::rc::Ref;
// ... modify the IL
let finalized_llil = mutable_llil.finalized();
finalized_llil.generate_ssa_form();Sourceimpl Ref<CoreWebsocketClient>
impl Ref<CoreWebsocketClient>
Sourcepub fn connect<'a, I, C>(
self,
host: &str,
headers: I,
callbacks: &'a C,
) -> Option<ActiveConnection<'a, C>>
pub fn connect<'a, I, C>( self, host: &str, headers: I, callbacks: &'a C, ) -> Option<ActiveConnection<'a, C>>
Initializes the web socket connection, returning the ActiveConnection, once dropped the
connection will be disconnected.
Connect to a given url, asynchronously. The connection will be run in a separate thread managed by the websocket provider.
Callbacks will be called on the thread of the connection, so be sure to ExecuteOnMainThread any long-running or gui operations in the callbacks.
If the connection succeeds, WebsocketClientCallback::connected will be called. On normal termination, WebsocketClientCallback::disconnected will be called.
If the connection succeeds but later fails, WebsocketClientCallback::error will be called
and shortly thereafter WebsocketClientCallback::disconnected will be called.
If WebsocketClientCallback::connected or WebsocketClientCallback::read return false, the
connection will be aborted.
host- Full url with scheme, domain, optionally port, and pathheaders- HTTP header keys and valuescallback- Callbacks for various websocket events